==> v1.0.2.tar.gz: aseprite/src/app/commands/cmd_goto_tab.cpp <==
/* Aseprite
 * Copyright (C) 2001-2013  David Capello
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "app/commands/command.h"

#include "app/app.h"
#include "app/ui/main_window.h"
#include "app/ui/tabs.h"

namespace app {

class GotoNextTabCommand : public Command {
public:
  GotoNextTabCommand();
  Command* clone() const OVERRIDE { return new GotoNextTabCommand(*this); }

protected:
  void onExecute(Context* context);
};

GotoNextTabCommand::GotoNextTabCommand()
  : Command("GotoNextTab",
            "Goto Next Tab",
            CmdUIOnlyFlag)
{
}

void GotoNextTabCommand::onExecute(Context* context)
{
  App::instance()->getMainWindow()->getTabsBar()->selectNextTab();
}

class GotoPreviousTabCommand : public Command {
public:
  GotoPreviousTabCommand();
  Command* clone() const OVERRIDE { return new GotoPreviousTabCommand(*this); }

protected:
  void onExecute(Context* context);
};

GotoPreviousTabCommand::GotoPreviousTabCommand()
  : Command("GotoPreviousTab",
            "Goto Previous tab",
            CmdRecordableFlag)
{
}

void GotoPreviousTabCommand::onExecute(Context* context)
{
  App::instance()->getMainWindow()->getTabsBar()->selectPreviousTab();
}

Command* CommandFactory::createGotoNextTabCommand()
{
  return new GotoNextTabCommand;
}

Command* CommandFactory::createGotoPreviousTabCommand()
{
  return new GotoPreviousTabCommand;
}

} // namespace app

==> v1.0.5.tar.gz: aseprite/src/app/commands/cmd_goto_tab.cpp <==
/* Aseprite
 * Copyright (C) 2001-2013  David Capello
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "app/commands/command.h"

#include "app/app.h"
#include "app/ui/main_window.h"
#include "app/ui/tabs.h"

namespace app {

class GotoNextTabCommand : public Command {
public:
  GotoNextTabCommand();
  Command* clone() const override { return new GotoNextTabCommand(*this); }

protected:
  void onExecute(Context* context);
};

GotoNextTabCommand::GotoNextTabCommand()
  : Command("GotoNextTab",
            "Goto Next Tab",
            CmdUIOnlyFlag)
{
}

void GotoNextTabCommand::onExecute(Context* context)
{
  App::instance()->getMainWindow()->getTabsBar()->selectNextTab();
}

class GotoPreviousTabCommand : public Command {
public:
  GotoPreviousTabCommand();
  Command* clone() const override { return new GotoPreviousTabCommand(*this); }

protected:
  void onExecute(Context* context);
};

GotoPreviousTabCommand::GotoPreviousTabCommand()
  : Command("GotoPreviousTab",
            "Goto Previous tab",
            CmdRecordableFlag)
{
}

void GotoPreviousTabCommand::onExecute(Context* context)
{
  App::instance()->getMainWindow()->getTabsBar()->selectPreviousTab();
}

Command* CommandFactory::createGotoNextTabCommand()
{
  return new GotoNextTabCommand;
}

Command* CommandFactory::createGotoPreviousTabCommand()
{
  return new GotoPreviousTabCommand;
}

} // namespace app
